==> dnet-mapreduce-jobs-1.1.3-BETA-20180521.103307-4-sources.jar: eu/dnetlib/data/mapreduce/hbase/broker/PIDEventFactory.java <==
package eu.dnetlib.data.mapreduce.hbase.broker;

import java.io.IOException;
import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import com.google.common.collect.Lists;
import eu.dnetlib.broker.objects.OpenAireEventPayload;
import eu.dnetlib.data.mapreduce.hbase.broker.mapping.HighlightFactory;
import eu.dnetlib.data.mapreduce.hbase.broker.mapping.OpenAireEventPayloadFactory;
import eu.dnetlib.data.mapreduce.hbase.broker.model.EventWrapper;
import eu.dnetlib.data.proto.FieldTypeProtos.StructuredProperty;
import eu.dnetlib.data.proto.OafProtos.Oaf;
import org.dom4j.DocumentException;

import static eu.dnetlib.data.mapreduce.hbase.broker.mapping.EventFactory.asEvent;

/**
 * Created by claudio on 26/07/16.
 */
public class PIDEventFactory {

	public static List<EventWrapper> process(final Oaf current, final Oaf other, final float trust)
			throws IOException, InterruptedException, DocumentException {
		return new PIDEventFactory().processPID(current, other, trust);
	}

	public List<EventWrapper> processPID(final Oaf current, final Oaf other, final float trust)
			throws IOException, InterruptedException, DocumentException {

		final List<StructuredProperty> pids = other.getEntity().getPidList();
		return Stream.concat(
			pids.stream()
				.map(p -> doProcessPID(current, other, p, Topic.ENRICH_MISSING_PID, trust)),
			pids.stream()
				.filter(p -> !hasPidValue(current, p.getValue()))
				.map(p -> doProcessPID(current, other, p, Topic.ENRICH_MORE_PID, trust)))
			.collect(Collectors.toList());
	}

	private EventWrapper doProcessPID(
			final Oaf current,
			final Oaf other,
			final StructuredProperty pidOther,
			final Topic topic,
			final float trust) {

		final Oaf.Builder prototype = Oaf.newBuilder(current);
		prototype.getEntityBuilder().addPid(pidOther);
		final Oaf oaf = prototype.build();

		final OpenAireEventPayload payload =
				HighlightFactory.highlightEnrichPid(OpenAireEventPayloadFactory.fromOAF(oaf.getEntity(), other.getEntity(), trust),
						Lists.newArrayList(pidOther));
		return EventWrapper.newInstance(
				asEvent(oaf.getEntity(), topic, payload, other.getEntity(), trust),
				topic.getValue());
	}

	private boolean hasPidValue(final Oaf oaf, final String value) {
		return oaf.getEntity().getPidList()
				.stream()
				.anyMatch(pid -> pid.getValue().equalsIgnoreCase(value));
	}
}

==> dnet-mapreduce-jobs-1.1.4-BETA-20180808.155854-72-sources.jar: eu/dnetlib/data/mapreduce/hbase/broker/PIDEventFactory.java <==
package eu.dnetlib.data.mapreduce.hbase.broker;

import static eu.dnetlib.data.mapreduce.hbase.broker.mapping.EventFactory.asEvent;

import java.io.IOException;
import java.util.Collection;
import java.util.List;
import java.util.Objects;
import java.util.function.Function;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import org.apache.commons.lang3.StringUtils;
import org.dom4j.DocumentException;

import com.google.common.collect.Lists;

import eu.dnetlib.broker.objects.OpenAireEventPayload;
import eu.dnetlib.data.mapreduce.hbase.broker.mapping.HighlightFactory;
import eu.dnetlib.data.mapreduce.hbase.broker.mapping.OpenAireEventPayloadFactory;
import eu.dnetlib.data.mapreduce.hbase.broker.model.EventWrapper;
import eu.dnetlib.data.proto.FieldTypeProtos.StructuredProperty;
import eu.dnetlib.data.proto.OafProtos.Oaf;

/**
 * Created by claudio on 26/07/16.
 */
public class PIDEventFactory {

	public static List<EventWrapper> process(final Oaf current, final Oaf other, final float trust)
			throws IOException, InterruptedException, DocumentException {
		return new PIDEventFactory().processPID(current, other, trust);
	}

	public List<EventWrapper> processPID(final Oaf current, final Oaf other, final float trust)
			throws IOException, InterruptedException, DocumentException {

		final Collection<StructuredProperty> pids = other.getEntity().getPidList()
				.stream()
				.collect(Collectors.toMap(
						p -> StringUtils.lowerCase(p.getValue()),
						Function.identity()))
				.values();

		final Stream<EventWrapper> more = pids.stream()
				.filter(p -> !hasPidValue(current, p.getValue()))
				.map(p -> doProcessPID(current, other, p, Topic.ENRICH_MORE_PID, trust));

		if (current.getEntity().getPidList().isEmpty()) { return Stream.concat(
				more,
				pids.stream().map(p -> doProcessPID(current, other, p, Topic.ENRICH_MISSING_PID, trust)))
				.collect(Collectors.toList()); }

		return more.collect(Collectors.toList());
	}

	private EventWrapper doProcessPID(
			final Oaf current,
			final Oaf other,
			final StructuredProperty pidOther,
			final Topic topic,
			final float trust) {

		final Oaf.Builder prototype = Oaf.newBuilder(current);
		prototype.getEntityBuilder().addPid(pidOther);
		final Oaf oaf = prototype.build();

		final OpenAireEventPayload payload =
				HighlightFactory.highlightEnrichPid(OpenAireEventPayloadFactory.fromOAF(oaf.getEntity(), other.getEntity(), trust),
						Lists.newArrayList(pidOther));
		return EventWrapper.newInstance(
				asEvent(oaf.getEntity(), topic, payload, other.getEntity(), trust),
				payload.getHighlight().getPids().stream().filter(Objects::nonNull).map(p -> p.getType() + ":" + p.getValue()).sorted()
						.collect(Collectors.joining(", ")),
				topic.getValue());
	}

	private boolean hasPidValue(final Oaf oaf, final String value) {
		return oaf.getEntity().getPidList()
				.stream()
				.anyMatch(pid -> pid.getValue().equalsIgnoreCase(value));
	}
}
